require "defines"
require "util"
require "config"

local function chunk_load(event)
	local x1 = event.area.left_top.x
    local y1 = event.area.left_top.y
    local x2 = event.area.right_bottom.x
    local y2 = event.area.right_bottom.y
	local surface = event.surface
	local resources = {}
	for key, entity in pairs(game.entity_prototypes) do
		if (entity.type == 'resource') then
			resources[#resources+1] = key
		end
	end
	
	local entities = surface.find_entities_filtered{area = {{x1, y1}, {x2, y2}}, type= "resource"}
	for i = 1, #entities do
		local entity = entities[i]
		entity.destroy()
	end
	
	for x = x1, x2 do
		for y = y1, y2 do
			if not (surface.get_tile(x,y).name == 'water' or surface.get_tile(x,y).name == 'deepwater') then
				if layout == 'radial' then
					local n = math.atan(y/x)
					if x == 0 and y == 0 then
						n = 0
					end
					if y >= 0 and x < 0 then 
						n = math.pi+n 
					end
					if y < 0 and x < 0 then
						n = -math.pi+n
					end
					if y < 0 and x == 0 then
						n = -math.pi/2
					end
					if y > 0 and x == 0 then
						n = math.pi/2
					end
					if n < 0 then n = n + 2*math.pi end
					n = n / (math.pi*2)
					n = math.ceil(n * #resources)
					if n <= 0 then n = 1 end
					local name = resources[n]
					if name ~= 'crude-oil' or (x%2==0 and y%2==0) then
						local amount = oil_richness
						if name ~= 'crude-oil' then
							amount = resource_richness
						end
						surface.create_entity{name = name, position = {x, y}, amount = amount}
					end
				elseif layout == 'column' then
					local t = #resources*column_width
					local n = math.ceil((x%t)/column_width)
					if n <= 0 then n = #resources end
					name = resources[n]
					if name ~= 'crude-oil' or (x%2==0 and y%2==0) then
						local amount = oil_richness
						if name ~= 'crude-oil' then
							amount = resource_richness
						end
						surface.create_entity{name = name, position = {x, y}, amount = amount}
					end
				end
			end
		end
	end
end
script.on_event(defines.events.on_chunk_generated, chunk_load)